#
# spec file for package python-netpbmfile
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%define skip_python36 1
%define packagename netpbmfile
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-netpbmfile
Version:        2023.8.30
Release:        1.3
Summary:        Read and write image files in the Netpbm format
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://www.lfd.uci.edu/~gohlke/
Source:         https://github.com/cgohlke/netpbmfile/archive/v%{version}.tar.gz#/%{packagename}-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module matplotlib >= 3.2}
BuildRequires:  %{python_module numpy >= 1.15}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-matplotlib >= 3.2
Requires:       python-numpy >= 1.15
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Netpbmfile is a Python library to read and write image files in the Netpbm
format.

%prep
%setup -q -n %{packagename}-%{version}
# Fix warning: wrong end-of-line encoding
sed -i 's/\r//' README.rst

%build
%python_build

%install
%python_install
for p in %{packagename} ; do
    %python_clone -a %{buildroot}%{_bindir}/$p
done

%python_expand %fdupes %{buildroot}%{$python_sitelib}
%prepare_alternative %{packagename}

%post
%python_install_alternative %{packagename}

%postun
%python_uninstall_alternative %{packagename}

%check
# Test not provided

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/%{packagename}
%{python_sitelib}/*egg-info/
%{python_sitelib}/%{packagename}/

%changelog
* Tue Dec 12 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.8.30:
  * Fix linting issues.
  * Add py.typed marker.
  * Drop support for Python 3.8 and numpy < 1.21 (NEP29).
  * Improve type hints.
  * Several breaking changes:
  * Rename magicnum to magicnumber (breaking).
  * Rename tupltypes to tupltype (breaking).
  * Change magicnumber and header properties to str (breaking).
  * Replace pam parameter with magicnumber (breaking).
  * Move byteorder parameter from NetpbmFile.asarray to NetpbmFile (breaking).
  * Fix shape and axes properties for multi-image files.
  * Add maxval and tupltype parameters to NetpbmFile.fromdata and imwrite.
  * Add option to write comment to PNM and PAM files.
  * Support writing PGX and text formats.
  * Add Google style docstrings.
  * Add unittests.
  * Read multi-image files.
  * Fix reading ASCII formats with trailing comments.
  * Fix writing maxval=1, depth=1 binary images.
  * Use tifffile.imshow for multi-image arrays if installed.
  * Change tupltypes to bytes according to specification (breaking).
  * Allow space after token value in PAM.
  * Update metadata.
  * Add type hints.
  * Support reading PF4 RGBA FloatMaps.
  * Drop support for Python 3.7 and numpy < 1.19 (NEP29).
  * Fix unclosed file warnings.
  * Support reading PGX JPEG2000 reference images.
* Fri Feb 19 2021 andy great <andythe_great@pm.me>
- Skip python36 because python-numpy does not support it.
* Thu Nov 26 2020 andy great <andythe_great@pm.me>
- Update to version 2020.10.18.
  * Disallow comments after last value in PNM headers.
- Update since 2020.1.1
    Remove support for Python 3.6.
    Support os.PathLike file names.
* Fri Jul 31 2020 andy great <andythe_great@pm.me>
- Update spec file to use python alternative.
* Wed Jun  3 2020 andy great <andythe_great@pm.me>
- Initial package release.
